import '../uibit.dart';

class Button {
  ///
  static Widget icon({dynamic icon, VoidCallback onPressed, Color color, bool rounded = false, Color round, double size, EdgeInsetsGeometry padding, bool disable = false, bool blur = false, Text withText, Axis axis = Axis.vertical}) {
    var voidCallback = onPressed ?? () {};
    var backColor = round ?? kColor.opa(0.7);
    if (disable) {
      voidCallback = null;
      backColor = backColor.withOpacity(0.5);
    }

    var _icon;

    if (icon is Icon) _icon = icon;
    if (icon is IconData) _icon = color != null ? Icon(icon, color: color) : Icon(icon);

    final btn = IconButton(
      iconSize: size ?? kSize.icon,
      onPressed: voidCallback,
      icon: _icon,
    );

    if (rounded) {
      final parent = Container(
        padding: padding ?? EdgeInsets.all(8.0),
        decoration: BoxDecoration(borderRadius: kRadius.all, color: backColor),
        child: btn,
      );
      return Center(
        child: ClipOval(
          child: blur ? BlurMask(child: parent) : parent,
        ),
      );
    }

    if (withText != null) {
      if (axis == Axis.vertical) {
        return Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Center(child: btn),
            Center(child: withText),
          ],
        );
      } else {
        return Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Center(child: btn),
            Center(child: withText),
          ],
        );
      }
    }
    return Center(child: btn);
  }


  static Widget rounded({VoidCallback onPressed, Color color, Color backColor, TextStyle style, String text, double height, bool disable = false, bool gradient = false, IconData icon,EdgeInsetsGeometry margin,EdgeInsetsGeometry padding}) {
    var styleText = style ?? KTextStyle.button;
    backColor = backColor ?? kColor.light8;
    if (color != null) {
      styleText = styleText.copyWith(color: color);
    }

    if (disable) backColor = backColor.withOpacity(0.5);

    var decoration = BoxDecoration(borderRadius: kRadius.all, color: backColor);
    if (gradient) {
      decoration = decoration.copyWith(
        gradient: kDecoration.gradient,
        boxShadow: kDecoration.boxShadow,
      );
      styleText = styleText.copyWith(color: kColor.light0);
    }

    Widget content = Text(text, style: styleText);

    if (icon != null) {
      content = Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          content,
          SizedBox(width: kSize.edgeSmall),
          Icon(
            icon,
            color: styleText.color,
            size: 25,
          )
        ],
      );
    }

    return Container(
      height: height ?? 35,
      decoration: decoration,
      child: Material(
        color: kColor.none,
        borderRadius: kRadius.all,
        child: InkWell(
          onTap: onPressed,
          borderRadius: kRadius.all,
          child: Container(
            margin: margin??EdgeInsets.all(2.5),
            padding: padding??EdgeInsets.symmetric(horizontal: kSize.edge * 2),
            alignment: Alignment.center,
            child: content,
          ),
        ),
      ),
    );
  }

  static Widget chip({String text, bool selected = false, EdgeInsetsGeometry margin}) {
    return Padding(
      padding: margin ?? EdgeInsets.all(8.0),
      child: Chip(
        label: Text(
          text,
          style: selected ? KTextStyle.chipBold : KTextStyle.chipNormal,
        ),
      ),
    );
  }
}
