import '../uibit.dart';

class FadeInWidgetStateless extends StatelessWidget {
  final Widget child;
  final Duration duration;
  final Duration delay;
  final bool selected;
  final Tween<double> tween;

  const FadeInWidgetStateless({Key key, this.duration, this.selected, this.child, this.tween, this.delay}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return FadeInWidget(
      child: child,
      duration: duration,
      selected: selected,
      tween: tween,
    );
  }
}

class FadeInWidget extends StatefulWidget {
  final Widget child;
  final Duration duration;
  final Duration delay;
  final bool selected;
  final Tween<double> tween;

  const FadeInWidget({Key key, @required this.child, this.duration, this.selected, this.tween, this.delay}) : super(key: key);

  @override
  _FadeInWidgetState createState() => _FadeInWidgetState();
}

class _FadeInWidgetState extends State<FadeInWidget> with SingleTickerProviderStateMixin {
  AnimController anim;

  bool faded = false;

  @override
  void initState() {
    anim = AnimController(vsync: this, duration: widget.duration ?? kTabScrollDuration);
    super.initState();
  }

  @override
  void dispose() {
    anim.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: Future.delayed(widget.delay??Duration.zero, () {
        if (!faded) {
          faded = true;
          anim.reset();
          anim.forward();
        }
      }),
      builder: (c, s) {
        Tween<double> tween = widget.tween ?? Tween(begin: 0.0, end: 1.0);
        return FadeTransition(
          opacity: tween.animate(anim),
          child: widget.child,
        );
      },
    );
  }
}
