import 'dart:math';

import 'package:flutter/material.dart';
import '../uibit.dart';

class Toast {
  IconData _iconData;
  String _string;
  BuildContext mContext;

  Toast({BuildContext context, String msg = "", IconData icon = Icons.error}) {
    mContext = context ?? Uikit.context;
    _iconData = icon;
    _string = msg;
  }

  void show({Future future, Duration delay}) async {
    if (mContext == null) return;
    OverlayState overlayState = Overlay.of(mContext);
    OverlayEntry overlayEntry = OverlayEntry(builder: _build);
    overlayState.insert(overlayEntry);
    await (future ?? Future.delayed(delay ?? Duration(seconds: 2)));
    overlayEntry.remove();
  }

  Widget _build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    var w2 = screenSize.width / 2;
    var h2 = screenSize.height / 2;

    var w2w = max(w2 / 1.25, 250.0);

    return Positioned(
      top: h2 - w2w / 2,
      left: w2 - w2w / 2,
      child: Material(
        color: Colors.transparent,
        child: Container(
          width: w2w,
          height: w2w,
          padding: EdgeInsets.fromLTRB(10, 10, 10, 10),
          decoration: BoxDecoration(color: Colors.black54, borderRadius: BorderRadius.all(Radius.circular(w2w / 10))),
          child: Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Icon(_iconData, color: Colors.white, size: 35),
                SizedBox(height: 15),
                Text(_string),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
